@@ -7,6 +7,9 @@ from copy import copy
 from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.step_performers.column_steps.change_column_dtype_code_chunk import ChangeColumnDtypeCodeChunk
+from mitosheet.code_chunks.step_performers.column_steps.refresh_dependant_columns_code_chunk import RefreshDependantColumnsCodeChunk
 
 from mitosheet.errors import get_recent_traceback, make_invalid_column_type_change_error
 from mitosheet.sheet_functions.types import to_int_series
@@ -23,9 +26,8 @@ from mitosheet.sheet_functions.types.utils import (get_datetime_format,
                                                    is_timedelta_dtype)
 from mitosheet.state import FORMAT_DEFAULT, State
 from mitosheet.step_performers.column_steps.set_column_formula import (
-    refresh_dependant_columns, transpile_dependant_columns)
+    refresh_dependant_columns)
 from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
 from mitosheet.types import ColumnID
 
 
@@ -45,10 +47,6 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
     def step_type(cls) -> str:
         return 'change_column_dtype'
 
-    @classmethod
-    def step_display_name(cls) -> str:
-        return 'Change column dtype'
-
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         sheet_index = params['sheet_index']
@@ -220,142 +218,27 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
+        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-        sheet_index: int,
-        column_id: ColumnID,
-        old_dtype: str,
-        new_dtype: str
-    ) -> List[str]:
-        df_name = post_state.df_names[sheet_index]
-        column_header = post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
-        transpiled_column_header = column_header_to_transpiled_code(column_header)
-
-        column = prev_state.dfs[sheet_index][column_header]
-
-        conversion_code = f'{df_name}[{transpiled_column_header}]'
-        if is_bool_dtype(old_dtype):
-            if is_bool_dtype(new_dtype):
-                pass
-            elif is_int_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'int\')'
-            elif is_float_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'float\')'
-            elif is_string_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'str\')'
-            elif is_datetime_dtype(new_dtype):
-                raise make_invalid_column_type_change_error(
-                    column_header,
-                    old_dtype,
-                    new_dtype
-                )
-            elif is_timedelta_dtype(new_dtype):
-                raise make_invalid_column_type_change_error(
-                    column_header,
-                    old_dtype,
-                    new_dtype
-                )
-        elif is_int_dtype(old_dtype):
-            if is_bool_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].fillna(False).astype(\'bool\')'
-            elif is_int_dtype(new_dtype):
-                pass
-            elif is_float_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'float\')'
-            elif is_string_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'str\')'
-            elif is_datetime_dtype(new_dtype):
-                conversion_code = f'pd.to_datetime({df_name}[{transpiled_column_header}], unit=\'s\', errors=\'coerce\')'
-            elif is_timedelta_dtype(new_dtype):
-                conversion_code = f'pd.to_timedelta({df_name}[{transpiled_column_header}], unit=\'s\', errors=\'coerce\')'
-        elif is_float_dtype(old_dtype):
-            if is_bool_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].fillna(False).astype(\'bool\')'
-            elif is_int_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].fillna(0).astype(\'int\')'
-            elif is_float_dtype(new_dtype):
-                pass
-            elif is_string_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'str\')'
-            elif is_datetime_dtype(new_dtype):
-                conversion_code = f'pd.to_datetime({df_name}[{transpiled_column_header}], unit=\'s\', errors=\'coerce\')'
-            elif is_timedelta_dtype(new_dtype):
-                conversion_code = f'pd.to_timedelta({df_name}[{transpiled_column_header}], unit=\'s\', errors=\'coerce\')'
-        elif is_string_dtype(old_dtype):
-            if is_bool_dtype(new_dtype):
-                conversion_code = f'to_boolean_series({df_name}[{transpiled_column_header}])'
-            elif is_int_dtype(new_dtype):
-                conversion_code = f'to_int_series({df_name}[{transpiled_column_header}])'
-            elif is_float_dtype(new_dtype):
-                conversion_code = f'to_float_series({df_name}[{transpiled_column_header}])'
-            elif is_string_dtype(new_dtype):
-                pass
-            elif is_datetime_dtype(new_dtype):
-                # Guess the datetime format to the best of Pandas abilities
-                datetime_format = get_datetime_format(column)
-                if datetime_format is not None:
-                    conversion_code = f'pd.to_datetime({df_name}[{transpiled_column_header}], format=\'{datetime_format}\', errors=\'coerce\')'
-                else:
-                    conversion_code = f'pd.to_datetime({df_name}[{transpiled_column_header}], infer_datetime_format=True, errors=\'coerce\')'
-            elif is_timedelta_dtype(new_dtype):
-                conversion_code = f'pd.to_timedelta({df_name}[{transpiled_column_header}], errors=\'coerce\')'
-        elif is_datetime_dtype(old_dtype):
-            if is_bool_dtype(new_dtype):
-                conversion_code = f'~{df_name}[{transpiled_column_header}].isnull()'
-            elif is_int_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'int\') / 10**9'
-            elif is_float_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'int\').astype(\'float\') / 10**9'
-            elif is_string_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].dt.strftime(\'%Y-%m-%d %X\')'
-            elif is_datetime_dtype(new_dtype):
-                pass
-            elif is_timedelta_dtype(new_dtype):
-                raise make_invalid_column_type_change_error(
-                    column_header,
-                    old_dtype,
-                    new_dtype
-                )
-        elif is_timedelta_dtype(old_dtype):
-            if is_bool_dtype(new_dtype):
-                conversion_code = f'~{df_name}[{transpiled_column_header}].isnull()'
-            elif is_int_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].dt.total_seconds().astype(\'int\')'
-            elif is_float_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].dt.total_seconds()'
-            elif is_string_dtype(new_dtype):
-                conversion_code = f'{df_name}[{transpiled_column_header}].astype(\'str\')'
-            elif is_datetime_dtype(new_dtype):
-                raise make_invalid_column_type_change_error(
-                    column_header,
-                    old_dtype,
-                    new_dtype
-                )
-            elif is_timedelta_dtype(new_dtype):
-                pass
-
-        code = [f'{df_name}[{transpiled_column_header}] = {conversion_code}']
-        # If we have pandas included, then add pandas to the transpiled code
-        if 'pd.to_datetime' in conversion_code:
-            code.insert(0, 'import pandas as pd')
-        code = code + transpile_dependant_columns(post_state, sheet_index, column_id)
-
-        return code
-
-    @classmethod
-    def describe( # type: ignore
-        cls,
-        sheet_index: int,
-        column_id: ColumnID,
-        old_dtype: str,
-        new_dtype: str,
-        df_names=None,
-        **params
-    ) -> str:
-        return f'Changed {column_id} from {old_dtype} to {new_dtype}'
+    ) -> List[CodeChunk]:
+        return [
+            ChangeColumnDtypeCodeChunk(prev_state, post_state, params, execution_data),
+            # Note that we also refresh all the dependant columns, starting with the set cell value
+            RefreshDependantColumnsCodeChunk(
+                prev_state, 
+                post_state, 
+                # We construct the params for this CodeChunk as well
+                {
+                    'sheet_index': params['sheet_index'],
+                    'column_id': params['column_id'],
+                }, 
+                None
+            )
+        ]
 
     @classmethod
     def get_modified_dataframe_indexes( # type: ignore
